==> react-common-bootstrap-1.0.19.tgz: package/form/CustomFormField.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useRef } from 'react';
import { DisplayErrorCtx } from './CustomForm';
const CustomFormField = ({
  label = null,
  value = null,
  onChange = () => {},
  type = 'text',
  selectValues = [],
  className = '',
  name = '',
  disabled = false,
  isValid = true,
  feedback = '',
  emptySelectOption = false,
  prefix = null,
  ...props
}) => {
  const displayError = useContext(DisplayErrorCtx);
  const renderFileInput = () => {
    const fileRef = useRef();
    return /*#__PURE__*/React.createElement("input", _extends({
      ref: fileRef,
      type: "file",
      onChange: _ => onChange(fileRef.current.files)
    }, props));
  };
  const renderTextarea = () => /*#__PURE__*/React.createElement("textarea", _extends({
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    disabled: disabled,
    name: name
  }, props));
  const renderSelect = () => /*#__PURE__*/React.createElement("select", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    name: name,
    disabled: disabled
  }), emptySelectOption && /*#__PURE__*/React.createElement("option", {
    value: ''
  }), selectValues.map(({
    value,
    label
  }, index) => /*#__PURE__*/React.createElement("option", {
    key: index,
    value: value
  }, label == null ? value : label)));
  const renderInput = () => /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    type: type,
    name: name,
    disabled: disabled
  }));
  const renderCheckbox = () => /*#__PURE__*/React.createElement("div", {
    className: "form-group form-check custom-checkbox"
  }, /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-check-input ${displayError && !isValid && 'is-invalid'}`,
    checked: value,
    onChange: onChange,
    type: "checkbox",
    name: name,
    disabled: disabled
  })), /*#__PURE__*/React.createElement("label", {
    className: "form-check-label"
  }, label));
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, label != null && type != 'checkbox' && /*#__PURE__*/React.createElement("label", null, typeof label === 'string' ? label : label()), /*#__PURE__*/React.createElement("div", {
    className: "input-group mb-3"
  }, prefix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof prefix === 'function' ? prefix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, prefix)), type === 'select' ? renderSelect() : type === 'textarea' ? renderTextarea() : type === 'checkbox' ? renderCheckbox() : type === 'file' ? renderFileInput() : renderInput(), displayError && !isValid && feedback != '' && /*#__PURE__*/React.createElement("div", {
    className: "invalid-feedback"
  }, feedback)));
};
export default CustomFormField;

==> react-common-bootstrap-1.0.21.tgz: package/form/CustomFormField.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useRef } from 'react';
import { DisplayErrorCtx } from './CustomForm';
const CustomFormField = ({
  label = null,
  value = null,
  onChange = () => {},
  type = 'text',
  selectValues = [],
  className = '',
  name = '',
  disabled = false,
  isValid = true,
  feedback = '',
  emptySelectOption = false,
  prefix = null,
  ...props
}) => {
  const displayError = useContext(DisplayErrorCtx);
  const renderFileInput = () => {
    const fileRef = useRef();
    return /*#__PURE__*/React.createElement("input", _extends({
      ref: fileRef,
      type: "file",
      onChange: _ => onChange(fileRef.current.files)
    }, props));
  };
  const renderTextarea = () => /*#__PURE__*/React.createElement("textarea", _extends({
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    disabled: disabled,
    name: name
  }, props));
  const renderSelect = () => /*#__PURE__*/React.createElement("select", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    name: name,
    disabled: disabled
  }), emptySelectOption && /*#__PURE__*/React.createElement("option", {
    value: ''
  }), selectValues.map(({
    value,
    label
  }, index) => /*#__PURE__*/React.createElement("option", {
    key: index,
    value: value
  }, label == null ? value : label)));
  const renderInput = () => /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    type: type,
    name: name,
    disabled: disabled
  }));
  const renderCheckbox = () => /*#__PURE__*/React.createElement("div", {
    className: "form-group form-check custom-checkbox"
  }, /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-check-input ${displayError && !isValid && 'is-invalid'}`,
    checked: value,
    onChange: onChange,
    type: "checkbox",
    name: name,
    disabled: disabled
  })), /*#__PURE__*/React.createElement("label", {
    className: "form-check-label"
  }, label));
  return /*#__PURE__*/React.createElement("div", {
    className: `custom-form-field ${className}`
  }, label != null && type != 'checkbox' && /*#__PURE__*/React.createElement("label", null, typeof label === 'string' ? label : label()), /*#__PURE__*/React.createElement("div", {
    className: "input-group"
  }, prefix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof prefix === 'function' ? prefix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, prefix)), type === 'select' ? renderSelect() : type === 'textarea' ? renderTextarea() : type === 'checkbox' ? renderCheckbox() : type === 'file' ? renderFileInput() : renderInput(), displayError && !isValid && feedback != '' && /*#__PURE__*/React.createElement("div", {
    className: "invalid-feedback"
  }, feedback)));
};
export default CustomFormField;
